import * as pulumi from "@pulumi/pulumi";
/**
 * The ``postgresql.DefaultPrivileges`` resource creates and manages default privileges given to a user for a database schema.
 *
 * > **Note:** This resource needs Postgresql version 9 or above.
 *
 * ## Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as postgresql from "@pulumi/postgresql";
 *
 * const readOnlyTables = new postgresql.DefaultPrivileges("read_only_tables", {
 *     role: "test_role",
 *     database: "test_db",
 *     schema: "public",
 *     owner: "db_owner",
 *     objectType: "table",
 *     privileges: ["SELECT"],
 * });
 * ```
 *
 * ## Examples
 *
 * ### Grant default privileges for tables to "currentRole" role:
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as postgresql from "@pulumi/postgresql";
 *
 * const grantTablePrivileges = new postgresql.DefaultPrivileges("grant_table_privileges", {
 *     database: exampleDb.name,
 *     role: "current_role",
 *     owner: "owner_role",
 *     schema: "public",
 *     objectType: "table",
 *     privileges: [
 *         "SELECT",
 *         "INSERT",
 *         "UPDATE",
 *     ],
 * });
 * ```
 * Whenever the `ownerRole` creates a new table in the `public` schema, the `currentRole` is automatically granted SELECT, INSERT, and UPDATE privileges on that table.
 *
 * ### Revoke default privileges for functions for "public" role:
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as postgresql from "@pulumi/postgresql";
 *
 * const revokePublic = new postgresql.DefaultPrivileges("revoke_public", {
 *     database: exampleDb.name,
 *     role: "public",
 *     owner: "object_owner",
 *     objectType: "function",
 *     privileges: [],
 * });
 * ```
 *
 * @deprecated postgresql.DefaultPrivileg has been deprecated in favor of postgresql.DefaultPrivileges
 */
export declare class DefaultPrivileg extends pulumi.CustomResource {
    /**
     * Get an existing DefaultPrivileg resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: DefaultPrivilegState, opts?: pulumi.CustomResourceOptions): DefaultPrivileg;
    /**
     * Returns true if the given object is an instance of DefaultPrivileg.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DefaultPrivileg;
    /**
     * The database to grant default privileges for this role.
     */
    readonly database: pulumi.Output<string>;
    /**
     * The PostgreSQL object type to set the default privileges on (one of: table, sequence, function, type, schema).
     */
    readonly objectType: pulumi.Output<string>;
    /**
     * Specifies the role that creates objects for which the default privileges will be applied.
     */
    readonly owner: pulumi.Output<string>;
    /**
     * List of privileges (e.g., SELECT, INSERT, UPDATE, DELETE) to grant on new objects created by the owner. An empty list could be provided to revoke all default privileges for this role.
     */
    readonly privileges: pulumi.Output<string[]>;
    /**
     * The role that will automatically be granted the specified privileges on new objects created by the owner.
     */
    readonly role: pulumi.Output<string>;
    /**
     * The database schema to set default privileges for this role.
     */
    readonly schema: pulumi.Output<string | undefined>;
    /**
     * Permit the grant recipient to grant it to others
     */
    readonly withGrantOption: pulumi.Output<boolean | undefined>;
    /**
     * Create a DefaultPrivileg resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    /** @deprecated postgresql.DefaultPrivileg has been deprecated in favor of postgresql.DefaultPrivileges */
    constructor(name: string, args: DefaultPrivilegArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering DefaultPrivileg resources.
 */
export interface DefaultPrivilegState {
    /**
     * The database to grant default privileges for this role.
     */
    database?: pulumi.Input<string>;
    /**
     * The PostgreSQL object type to set the default privileges on (one of: table, sequence, function, type, schema).
     */
    objectType?: pulumi.Input<string>;
    /**
     * Specifies the role that creates objects for which the default privileges will be applied.
     */
    owner?: pulumi.Input<string>;
    /**
     * List of privileges (e.g., SELECT, INSERT, UPDATE, DELETE) to grant on new objects created by the owner. An empty list could be provided to revoke all default privileges for this role.
     */
    privileges?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The role that will automatically be granted the specified privileges on new objects created by the owner.
     */
    role?: pulumi.Input<string>;
    /**
     * The database schema to set default privileges for this role.
     */
    schema?: pulumi.Input<string>;
    /**
     * Permit the grant recipient to grant it to others
     */
    withGrantOption?: pulumi.Input<boolean>;
}
/**
 * The set of arguments for constructing a DefaultPrivileg resource.
 */
export interface DefaultPrivilegArgs {
    /**
     * The database to grant default privileges for this role.
     */
    database: pulumi.Input<string>;
    /**
     * The PostgreSQL object type to set the default privileges on (one of: table, sequence, function, type, schema).
     */
    objectType: pulumi.Input<string>;
    /**
     * Specifies the role that creates objects for which the default privileges will be applied.
     */
    owner: pulumi.Input<string>;
    /**
     * List of privileges (e.g., SELECT, INSERT, UPDATE, DELETE) to grant on new objects created by the owner. An empty list could be provided to revoke all default privileges for this role.
     */
    privileges: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The role that will automatically be granted the specified privileges on new objects created by the owner.
     */
    role: pulumi.Input<string>;
    /**
     * The database schema to set default privileges for this role.
     */
    schema?: pulumi.Input<string>;
    /**
     * Permit the grant recipient to grant it to others
     */
    withGrantOption?: pulumi.Input<boolean>;
}
