import * as pulumi from "@pulumi/pulumi";
/**
 * The ``postgresql.GrantRole`` resource creates and manages membership in a role to one or more other roles in a non-authoritative way.
 *
 * When using ``postgresql.GrantRole`` resource it is likely because the PostgreSQL role you are modifying was created outside of this provider.
 *
 * > **Note:** This resource needs PostgreSQL version 9 or above.
 *
 * ## Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as postgresql from "@pulumi/postgresql";
 *
 * const grantRoot = new postgresql.GrantRole("grant_root", {
 *     role: "root",
 *     grantRole: "application",
 *     withAdminOption: true,
 * });
 * ```
 *
 * > **Note:** If you use `postgresql.GrantRole` for a role that you also manage with a `postgresql.Role` resource, you need to ignore the changes of the `roles` attribute in the `postgresql.Role` resource or they will fight over what your role grants should be. e.g.:
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as postgresql from "@pulumi/postgresql";
 *
 * const bob = new postgresql.Role("bob", {name: "bob"});
 * const bobAdmin = new postgresql.GrantRole("bob_admin", {
 *     role: "bob",
 *     grantRole: "admin",
 * });
 * ```
 */
export declare class GrantRole extends pulumi.CustomResource {
    /**
     * Get an existing GrantRole resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: GrantRoleState, opts?: pulumi.CustomResourceOptions): GrantRole;
    /**
     * Returns true if the given object is an instance of GrantRole.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is GrantRole;
    /**
     * The name of the role that is added to `role`.
     */
    readonly grantRole: pulumi.Output<string>;
    /**
     * The name of the role that is granted a new membership.
     */
    readonly role: pulumi.Output<string>;
    /**
     * Giving ability to grant membership to others or not for `role`. (Default: false)
     */
    readonly withAdminOption: pulumi.Output<boolean | undefined>;
    /**
     * Create a GrantRole resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: GrantRoleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering GrantRole resources.
 */
export interface GrantRoleState {
    /**
     * The name of the role that is added to `role`.
     */
    grantRole?: pulumi.Input<string>;
    /**
     * The name of the role that is granted a new membership.
     */
    role?: pulumi.Input<string>;
    /**
     * Giving ability to grant membership to others or not for `role`. (Default: false)
     */
    withAdminOption?: pulumi.Input<boolean>;
}
/**
 * The set of arguments for constructing a GrantRole resource.
 */
export interface GrantRoleArgs {
    /**
     * The name of the role that is added to `role`.
     */
    grantRole: pulumi.Input<string>;
    /**
     * The name of the role that is granted a new membership.
     */
    role: pulumi.Input<string>;
    /**
     * Giving ability to grant membership to others or not for `role`. (Default: false)
     */
    withAdminOption?: pulumi.Input<boolean>;
}
